Issue class

Generic Crashlytics issue interface.

Constructors

Issue({required String id, required String title, required String subtitle, required String appVersion})
const
Issue.fromJson(Map<String, dynamic> json)
factory

Properties

appVersion String
The application version of the Crashlytics issue.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The ID of the Crashlytics issue.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
The subtitle of the Crashlytics issue.
final
title String
The title of the Crashlytics issue.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited