LiteralExpression<T extends Object> class final

A literal expression that wraps a constant value.

Inheritance

Constructors

LiteralExpression(T literal)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
literal → T
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

equals(Expression<T> other) Equals<T>
Creates an equality comparison expression.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(Expression<T> other) NotEquals<T>
Creates an inequality comparison expression.
inherited
runtimeValue() → T
Evaluates this expression to get its runtime value.
override
toCEL() String
Converts this expression to CEL (Common Expression Language) format.
inherited
toJSON() String
Converts this expression to JSON for serialization.
inherited
toString() String
A string representation of this object.
override
value() → T
Gets the runtime value of this expression.
inherited
when<R extends Object>({required Expression<R> then, required Expression<R> otherwise}) If<R>
Creates a conditional expression (ternary operator).
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited