NotEquals<T extends Object> class
final
Inequality comparison expression.
- Inheritance
-
- Object
- Expression<
bool> - ComparableExpression<
T> - NotEquals
Constructors
-
NotEquals(Expression<
T> lhs, Expression<T> rhs) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lhs
→ Expression<
T> -
finalinherited
-
rhs
→ Expression<
T> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
equals(
Expression< bool> other) → Equals<bool> -
Creates an equality comparison expression.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notEquals(
Expression< bool> other) → NotEquals<bool> -
Creates an inequality comparison expression.
inherited
-
runtimeValue(
) → bool -
Evaluates this expression to get its runtime value.
override
-
toCEL(
) → String -
Converts this expression to CEL (Common Expression Language) format.
inherited
-
toJSON(
) → String -
Converts this expression to JSON for serialization.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
value(
) → bool -
Gets the runtime value of this expression.
inherited
-
when<
R extends Object> ({required Expression< R> then, required Expression<R> otherwise}) → If<R> -
Creates a conditional expression (ternary operator).
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited