SelectParamInput<T extends Object> class
Single-select input from a list of options.
- Inheritance
-
- Object
- ParamInput<
T> - SelectParamInput
Constructors
-
SelectParamInput({required List<
SelectOption< options})T> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ List<
SelectOption< T> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited