StringParam class

A string parameter.

Reads from environment variables at runtime.

Inheritance

Constructors

StringParam(String name, ParamOptions<String>? options)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The environment variable name for this parameter.
finalinherited
options → ParamOptions<String>?
Configuration options for this parameter.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

equals(Expression<String> other) → Equals<String>
Creates an equality comparison expression.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(Expression<String> other) → NotEquals<String>
Creates an inequality comparison expression.
inherited
runtimeValue() → String
Evaluates this expression to get its runtime value.
override
toCEL() → String
Converts this expression to CEL (Common Expression Language) format.
inherited
toJSON() → String
Converts this expression to JSON for serialization.
inherited
toSpec() → WireParamSpec<String>
Converts this parameter to its wire specification for deployment.
inherited
toString() → String
A string representation of this object.
inherited
value() → String
Returns the parameter value at runtime.
inherited
when<R extends Object>({required Expression<R> then, required Expression<R> otherwise}) → If<R>
Creates a conditional expression (ternary operator).
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited