projectID top-level property

Param<String> projectID
final

Built-in parameter that resolves to the Cloud project ID.

This parameter is always available and does not need to be defined. The value is read from the FIREBASE_CONFIG environment variable.

Example:

firebase.https.onRequest(
  name: 'info',
  (request) async {
    return Response.ok('Project: ${projectID.value()}');
  },
);

Implementation

final internal.Param<String> projectID = internal.ParamInput.projectId;