storageBucket top-level property

Param<String> storageBucket
final

Built-in parameter that resolves to the Cloud Storage bucket.

Returns an empty string if Cloud Storage is not configured for the project.

Implementation

final internal.Param<String> storageBucket = internal.ParamInput.storageBucket;