Firebase class
Main Firebase Functions instance.
Provides access to all function namespaces (https, pubsub, firestore, etc.).
Properties
- adminApp → FirebaseApp
-
The initialized Firebase Admin SDK application instance.
final
- alerts → AlertsNamespace
-
Firebase Alerts namespace.
no setter
- database → DatabaseNamespace
-
Realtime Database triggers namespace.
no setter
- eventarc → EventarcNamespace
-
Eventarc triggers namespace.
no setter
- firestore → FirestoreNamespace
-
Firestore triggers namespace.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- https → HttpsNamespace
-
HTTPS triggers namespace.
no setter
- identity → IdentityNamespace
-
Identity Platform namespace.
no setter
- pubsub → PubSubNamespace
-
Pub/Sub triggers namespace.
no setter
- remoteConfig → RemoteConfigNamespace
-
Remote Config namespace.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduler → SchedulerNamespace
-
Scheduler namespace.
no setter
- storage → StorageNamespace
-
Cloud Storage triggers namespace.
no setter
- tasks → TasksNamespace
-
Task queue triggers namespace.
no setter
- testLab → TestLabNamespace
-
Test Lab triggers namespace.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited