ParamOptions<T extends Object> class
Configuration options for customizing parameter prompting behavior.
Matches the ParamOptions interface from the Node.js SDK.
Constructors
-
ParamOptions({T? defaultValue, String? label, String? description, ParamInput<
T> ? input}) -
const
Properties
- defaultValue → T?
-
Default value if parameter is not provided.
final
- description → String?
-
Detailed description of the parameter.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ ParamInput<
T> ? -
Input specification for how to collect the parameter value.
final
- label → String?
-
Short label for the parameter (shown in UI).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited