bucketPicker top-level constant
ResourceInput
const bucketPicker
Resource input for selecting a Cloud Storage bucket.
Use this with ParamInput.select or as the input option for a string
parameter to let users select from available buckets at deploy time.
Implementation
const bucketPicker = internal.ParamInput.bucketPicker;