storageBucket top-level property
Built-in parameter that resolves to the Cloud Storage bucket.
Returns an empty string if Cloud Storage is not configured for the project.
Implementation
final internal.Param<String> storageBucket = internal.ParamInput.storageBucket;